aboutsummaryrefslogtreecommitdiff
path: root/http/server.go
diff options
context:
space:
mode:
Diffstat (limited to 'http/server.go')
-rw-r--r--http/server.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/http/server.go b/http/server.go
index cbcb89e..9fae0a0 100644
--- a/http/server.go
+++ b/http/server.go
@@ -2,7 +2,7 @@
//
//Copyright (C) 2022 Alexander Kiryukhin <i@neonxp.dev>
//
//This file is part of github.com/neonxp/jsonrpc2 project.
//
//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ import (
"bufio"
"net/http"
- "github.com/neonxp/jsonrpc2/rpc"
+ "go.neonxp.dev/jsonrpc2/rpc"
)
type Server struct {
@@ -2,7 +2,7 @@
//Copyright (C) 2022 Alexander Kiryukhin <i@neonxp.dev>
//
-//This file is part of github.com/neonxp/jsonrpc2 project.
+//This file is part of go.neonxp.dev/jsonrpc2 project.
//
//This program is free software: you can redistribute it and/or modify